@@ -11,14 +11,14 @@ import tempfile
 import subprocess
 import base64
 import threading
+from pathlib import Path
+import pwd
 import pipes
 import uuid
 import codecs
 import atexit
 import signal
 
-from distutils.spawn import find_executable
-
 from ansible_runner.exceptions import ConfigurationError
 
 try:
@@ -46,6 +46,42 @@ def register_for_cleanup(folder):
     atexit.register(cleanup_folder, folder)
 
 
+def get_plugin_dir():
+    return os.path.abspath(os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", "display_callback"))
+
+
+def get_callback_dir():
+    return os.path.join(get_plugin_dir(), 'callback')
+
+
+def is_dir_owner(directory):
+    '''Returns True if current user is the owner of directory'''
+    current_user = pwd.getpwuid(os.geteuid()).pw_name
+    callback_owner = Path(directory).owner()
+    return bool(current_user == callback_owner)
+
+
+def callback_mount(copy_if_needed=False):
+    '''
+    Return a tuple that gives mount points for the standard out callback
+    in the form of (<host location>, <location in container>)
+    if copy_if_needed is set, and the install is owned by another user,
+    it will copy the plugin to a tmpdir for the mount in anticipation of SELinux problems
+    '''
+    container_dot_ansible = '/home/runner/.ansible'
+    rel_path = ('callback', '',)
+    host_path = os.path.join(get_plugin_dir(), *rel_path)
+    if copy_if_needed:
+        callback_dir = get_callback_dir()
+        if not is_dir_owner(callback_dir):
+            tmp_path = tempfile.mkdtemp(prefix='ansible_runner_plugins_')
+            register_for_cleanup(tmp_path)
+            host_path = os.path.join(tmp_path, 'callback')
+            shutil.copytree(callback_dir, host_path)
+    container_path = os.path.join(container_dot_ansible, 'plugins', *rel_path)
+    return (host_path, container_path)
+
+
 class Bunch(object):
 
     '''
@@ -280,7 +316,8 @@ class OutputEventFilter(object):
         self.suppress_ansible_output = suppress_ansible_output
 
     def flush(self):
-        self._handle.flush()
+        if self._handle:
+            self._handle.flush()
 
     def write(self, data):
         self._buffer.write(data)
@@ -319,8 +356,9 @@ class OutputEventFilter(object):
                     )
                     sys.stdout.write("\n")
                     sys.stdout.flush()
-                self._handle.write(stdout_actual + "\n")
-                self._handle.flush()
+                if self._handle:
+                    self._handle.write(stdout_actual + "\n")
+                    self._handle.flush()
 
             self._last_chunk = remainder
         else:
@@ -339,8 +377,9 @@ class OutputEventFilter(object):
                         sys.stdout.write(
                             line.encode('utf-8') if PY2 else line
                         )
-                    self._handle.write(line)
-                    self._handle.flush()
+                    if self._handle:
+                        self._handle.write(line)
+                        self._handle.flush()
                 self._buffer = StringIO()
                 # put final partial line back on buffer
                 if remainder:
@@ -352,7 +391,8 @@ class OutputEventFilter(object):
             self._emit_event(value)
             self._buffer = StringIO()
         self._event_callback(dict(event='EOF'))
-        self._handle.close()
+        if self._handle:
+            self._handle.close()
 
     def _emit_event(self, buffered_stdout, next_event_data=None):
         next_event_data = next_event_data or {}
@@ -371,7 +411,7 @@ class OutputEventFilter(object):
                 event_data['uuid'] = str(uuid.uuid4())
             self._counter += 1
             event_data['counter'] = self._counter
-            event_data['stdout'] = stdout_chunk[:-2] if len(stdout_chunk) > 2 else ""
+            event_data['stdout'] = stdout_chunk.rstrip('\n\r')
             n_lines = stdout_chunk.count('\n')
             event_data['start_line'] = self._start_line
             event_data['end_line'] = self._start_line + n_lines
@@ -392,7 +432,7 @@ def open_fifo_write(path, data):
     '''
     os.mkfifo(path, stat.S_IRUSR | stat.S_IWUSR)
     # If the data is a string instead of bytes, convert it before writing the fifo
-    if isinstance(data, string_types):
+    if type(data) == str:
         data = data.encode()
     threading.Thread(target=lambda p, d: open(p, 'wb').write(d),
                      args=(path, data)).start()
@@ -461,7 +501,7 @@ def cli_mounts():
     ]
 
 
-def santize_json_response(data):
+def sanitize_json_response(data):
     '''
     Removes warning message from response message emitted by Ansible
     command line utilities.
@@ -474,7 +514,7 @@ def santize_json_response(data):
 
 
 def get_executable_path(name):
-    exec_path = find_executable(name)
+    exec_path = shutil.which(name)
     if exec_path is None:
         raise ConfigurationError(f"{name} command not found")
     return exec_path
