@@ -3,7 +3,6 @@ import os
 import socket
 import concurrent.futures
 import time
-import tempfile
 
 import pytest
 import json
@@ -53,13 +52,19 @@ class TestStreamingUsage:
             assert '"ansible_facts"' in stdout
 
     @pytest.mark.parametrize("job_type", ['run', 'adhoc'])
-    def test_remote_job_interface(self, tmpdir, test_data_dir, job_type):
-        transmit_dir = os.path.join(test_data_dir, 'debug')
-        worker_dir = str(tmpdir.mkdir('for_worker'))
-        process_dir = str(tmpdir.mkdir('for_process'))
+    def test_remote_job_interface(self, tmp_path, project_fixtures, job_type):
+        transmit_dir = project_fixtures / 'debug'
+        worker_dir = tmp_path / 'for_worker'
+        worker_dir.mkdir()
+
+        process_dir = tmp_path / 'for_process'
+        process_dir.mkdir()
+
         job_kwargs = self.get_job_kwargs(job_type)
 
-        outgoing_buffer = tempfile.NamedTemporaryFile()
+        outgoing_buffer_file = tmp_path / 'buffer_out'
+        outgoing_buffer_file.touch()
+        outgoing_buffer = outgoing_buffer_file.open('b+r')
 
         transmitter = Transmitter(_output=outgoing_buffer, private_data_dir=transmit_dir, **job_kwargs)
 
@@ -75,7 +80,9 @@ class TestStreamingUsage:
         assert sent  # should not be blank at least
         assert b'zipfile' in sent
 
-        incoming_buffer = tempfile.NamedTemporaryFile()
+        incoming_buffer_file = tmp_path / 'buffer_in'
+        incoming_buffer_file.touch()
+        incoming_buffer = incoming_buffer_file.open('b+r')
 
         outgoing_buffer.seek(0)
 
@@ -90,17 +97,21 @@ class TestStreamingUsage:
         processor = Processor(_input=incoming_buffer, private_data_dir=process_dir)
         processor.run()
 
-        self.check_artifacts(process_dir, job_type)
+        self.check_artifacts(str(process_dir), job_type)
 
     @pytest.mark.parametrize("job_type", ['run', 'adhoc'])
-    def test_remote_job_by_sockets(self, tmpdir, test_data_dir, container_runtime_installed, job_type):
+    def test_remote_job_by_sockets(self, tmp_path, project_fixtures, job_type):
         """This test case is intended to be close to how the AWX use case works
         the process interacts with receptorctl with sockets
         sockets are used here, but worker is manually called instead of invoked by receptor
         """
-        transmit_dir = os.path.join(test_data_dir, 'debug')
-        worker_dir = str(tmpdir.mkdir('for_worker'))
-        process_dir = str(tmpdir.mkdir('for_process'))
+        transmit_dir = project_fixtures / 'debug'
+        worker_dir = tmp_path / 'for_worker'
+        worker_dir.mkdir()
+
+        process_dir = tmp_path / 'for_process'
+        process_dir.mkdir()
+
         job_kwargs = self.get_job_kwargs(job_type)
 
         def transmit_method(transmit_sockfile_write):
@@ -155,7 +166,116 @@ class TestStreamingUsage:
 
         assert set(os.listdir(worker_dir)) == {'artifacts', 'inventory', 'project', 'env'}
 
-        self.check_artifacts(process_dir, job_type)
+        self.check_artifacts(str(process_dir), job_type)
+
+
+@pytest.fixture
+def transmit_stream(project_fixtures, tmp_path):
+    outgoing_buffer = tmp_path / 'buffer'
+    outgoing_buffer.touch()
+
+    transmit_dir = project_fixtures / 'debug'
+    with outgoing_buffer.open('wb') as f:
+        transmitter = Transmitter(_output=f, private_data_dir=transmit_dir, playbook='debug.yml')
+        status, rc = transmitter.run()
+
+    assert rc in (None, 0)
+    assert status == 'unstarted'
+    return outgoing_buffer
+
+
+@pytest.fixture
+def worker_stream(transmit_stream, tmp_path):
+    ingoing_buffer = tmp_path / 'buffer2'  # basically how some demos work
+    ingoing_buffer.touch()
+
+    worker_dir = tmp_path / 'worker_dir'
+    worker_dir.mkdir()
+    with transmit_stream.open('rb') as out:
+        with ingoing_buffer.open('wb') as f:
+            worker = Worker(_input=out, _output=f, private_data_dir=worker_dir)
+            status, rc = worker.run()
+
+            assert rc in (None, 0)
+            assert status == 'successful'
+            return ingoing_buffer
+
+
+def test_worker_without_delete_no_dir(tmp_path, cli, transmit_stream):
+    worker_dir = tmp_path / 'for_worker'
+
+    with open(transmit_stream, 'rb') as stream:
+        worker_args = ['worker', '--private-data-dir', str(worker_dir)]
+        r = cli(worker_args, stdin=stream)
+
+    assert '{"eof": true}' in r.stdout
+    assert worker_dir.joinpath('project', 'debug.yml').exists()
+
+
+def test_worker_without_delete_dir_exists(tmp_path, cli, transmit_stream):
+    worker_dir = tmp_path / 'for_worker'
+    worker_dir.mkdir()
+
+    test_file_path = worker_dir / 'test_file.txt'
+    test_file_path.write_text('data\n')
+
+    with open(transmit_stream, 'rb') as stream:
+        worker_args = ['worker', '--private-data-dir', str(worker_dir)]
+        r = cli(worker_args, stdin=stream)
+
+    assert '{"eof": true}' in r.stdout
+    assert worker_dir.joinpath('project', 'debug.yml').exists()
+    assert test_file_path.exists()
+
+
+def test_worker_delete_no_dir(tmp_path, cli, transmit_stream):
+    """
+    Case where non-existing --delete is provided to worker command
+    it should always delete everything both before and after the run
+    """
+    worker_dir = tmp_path / 'for_worker'
+
+    with open(transmit_stream, 'rb') as f:
+        worker_args = ['worker', '--private-data-dir', str(worker_dir), '--delete']
+        r = cli(worker_args, stdin=f)
+
+    assert '{"eof": true}' in r.stdout
+    assert not worker_dir.exists()
+    assert not worker_dir.joinpath('project', 'debug.yml').exists()
+
+
+def test_worker_delete_dir_exists(tmp_path, cli, transmit_stream):
+    """
+    Case where non-existing --delete is provided to worker command
+    it should always delete everything both before and after the run
+    """
+    worker_dir = tmp_path / 'for_worker'
+    worker_dir.mkdir()
+
+    test_file = worker_dir / 'test_file.txt'
+    test_file.write_text('data\n')
+
+    with open(transmit_stream, 'rb') as f:
+        worker_args = ['worker', '--private-data-dir', str(worker_dir), '--delete']
+        r = cli(worker_args, stdin=f)
+
+    assert '{"eof": true}' in r.stdout
+    assert not worker_dir.exists()
+    assert not worker_dir.joinpath('project', 'debug.yml').exists()
+
+
+def test_process_with_custom_ident(tmp_path, cli, worker_stream):
+    process_dir = tmp_path / 'for_process'
+    process_dir.mkdir()
+
+    with open(worker_stream, 'rb') as f:
+        process_args = ['process', str(process_dir), '--ident', 'custom_ident']
+        r = cli(process_args, stdin=f)
+
+    assert 'Hello world!' in r.stdout
+    assert (process_dir / 'artifacts').exists()
+    assert (process_dir / 'artifacts' / 'custom_ident').exists()
+    assert (process_dir / 'artifacts' / 'custom_ident' / 'job_events').exists()
 
 
 def test_missing_private_dir_transmit(tmpdir):
@@ -173,8 +293,9 @@ def test_missing_private_dir_transmit(tmpdir):
     assert "private_data_dir path is either invalid or does not exist" in str(excinfo.value)
 
 
-def test_garbage_private_dir_worker(tmpdir):
-    worker_dir = str(tmpdir.mkdir('for_worker'))
+def test_garbage_private_dir_worker(tmp_path):
+    worker_dir = tmp_path / 'for_worker'
+    worker_dir.mkdir()
     incoming_buffer = io.BytesIO(
         b'{"kwargs": {"playbook": "debug.yml"}}\n{"zipfile": 5}\n\x01\x02\x03\x04\x05{"eof": true}\n')
     outgoing_buffer = io.BytesIO()
@@ -190,8 +311,9 @@ def test_garbage_private_dir_worker(tmpdir):
     assert b'"status": "error"' in sent
 
 
-def test_unparsable_private_dir_worker(tmpdir):
-    worker_dir = str(tmpdir.mkdir('for_worker'))
+def test_unparsable_private_dir_worker(tmp_path):
+    worker_dir = tmp_path / 'for_worker'
+    worker_dir.mkdir()
     incoming_buffer = io.BytesIO(b'')
     outgoing_buffer = io.BytesIO()
 
@@ -206,8 +328,9 @@ def test_unparsable_private_dir_worker(tmpdir):
     assert b'"status": "error"' in sent
 
 
-def test_unparsable_private_dir_processor(tmpdir):
-    process_dir = str(tmpdir.mkdir('for_process'))
+def test_unparsable_private_dir_processor(tmp_path):
+    process_dir = tmp_path / 'for_process'
+    process_dir.mkdir()
     incoming_buffer = io.BytesIO(b'')
 
     processor = run(
