@@ -3,20 +3,18 @@
 import os
 import pytest
 
-from tempfile import gettempdir
-
 from ansible_runner.config.inventory import InventoryConfig
 from ansible_runner.config._base import BaseExecutionMode
 from ansible_runner.exceptions import ConfigurationError
-from ansible_runner.utils import get_executable_path
+from ansible_runner.utils import get_executable_path, callback_mount
 
 
-def test_ansible_inventory_init_defaults():
+def test_ansible_inventory_init_defaults(tmp_path, patch_private_data_dir):
     rc = InventoryConfig()
 
     # Check that the private data dir is placed in our default location with our default prefix
     # and has some extra uniqueness on the end.
-    base_private_data_dir = os.path.join(gettempdir(), '.ansible-runner-')
+    base_private_data_dir = tmp_path.joinpath('.ansible-runner-').as_posix()
     assert rc.private_data_dir.startswith(base_private_data_dir)
     assert len(rc.private_data_dir) > len(base_private_data_dir)
 
@@ -86,13 +84,16 @@ def test_prepare_inventory_invalid_graph_response_format():
     assert "'graph' action supports only 'json' response format" == exc.value.args[0]
 
 
-@pytest.mark.parametrize('container_runtime', ['docker', 'podman'])
-def test_prepare_inventory_command_with_containerization(tmpdir, container_runtime):
+@pytest.mark.test_all_runtimes
+def test_prepare_inventory_command_with_containerization(tmp_path, runtime, mocker):
+    mocker.patch.dict('os.environ', {'HOME': str(tmp_path)}, clear=True)
+    tmp_path.joinpath('.ssh').mkdir()
+
     kwargs = {
-        'private_data_dir': tmpdir,
+        'private_data_dir': tmp_path,
         'process_isolation': True,
         'container_image': 'my_container',
-        'process_isolation_executable': container_runtime
+        'process_isolation_executable': runtime
     }
     rc = InventoryConfig(**kwargs)
     rc.ident = 'foo'
@@ -103,29 +104,48 @@ def test_prepare_inventory_command_with_containerization(tmpdir, container_runti
 
     assert rc.runner_mode == 'subprocess'
     extra_container_args = []
-    if container_runtime == 'podman':
+    if runtime == 'podman':
         extra_container_args = ['--quiet']
     else:
-        extra_container_args = ['--user={os.getuid()}']
+        extra_container_args = [f'--user={os.getuid()}']
 
-    expected_command_start = [container_runtime, 'run', '--rm', '--interactive', '--workdir', '/runner/project'] + \
-                             ['-v', '{}/.ssh/:/home/runner/.ssh/'.format(os.environ['HOME'])]
-    if container_runtime == 'podman':
-        expected_command_start += ['--group-add=root', '--ipc=host']
+    expected_command_start = [
+        runtime,
+        'run',
+        '--rm',
+        '--interactive',
+        '--workdir',
+        '/runner/project',
+        '-v', '{}/.ssh/:/home/runner/.ssh/'.format(rc.private_data_dir),
+        '-v', '{}/.ssh/:/root/.ssh/'.format(rc.private_data_dir),
+    ]
 
-    expected_command_start += ['-v', '{}/artifacts/:/runner/artifacts/:Z'.format(rc.private_data_dir)] + \
-        ['-v', '{}/:/runner/:Z'.format(rc.private_data_dir)] + \
-        ['--env-file', '{}/env.list'.format(rc.artifact_dir)] + \
-        extra_container_args + \
-        ['--name', 'ansible_runner_foo', 'my_container'] + \
-        ['ansible-inventory', '--list', '-i', '/tmp/inventory1', '-i', '/tmp/inventory2', '--yaml', '--playbook-dir'] + \
-        ['/tmp', '--vault-id', '1234', '--vault-password-file', '/tmp/password', '--output', '/tmp/inv_out.txt'] + \
-        ['--export']
+    if runtime == 'podman':
+        expected_command_start.extend(['--group-add=root', '--ipc=host'])
 
-    assert len(expected_command_start) == len(rc.command)
+    expected_command_start.extend([
+        '-v', '{}/artifacts/:/runner/artifacts/:Z'.format(rc.private_data_dir),
+        '-v', '{}/:/runner/:Z'.format(rc.private_data_dir),
+        '-v', '{0}:{1}:Z'.format(*callback_mount()),
+        '--env-file', '{}/env.list'.format(rc.artifact_dir),
+    ])
 
-    for index, element in enumerate(expected_command_start):
-        if '--user=' in element:
-            assert '--user=' in rc.command[index]
-        else:
-            assert rc.command[index] == element
+    expected_command_start.extend(extra_container_args)
+
+    expected_command_start.extend([
+        '--name',
+        'ansible_runner_foo',
+        'my_container',
+        'ansible-inventory',
+        '--list',
+        '-i', '/tmp/inventory1',
+        '-i', '/tmp/inventory2',
+        '--yaml',
+        '--playbook-dir', '/tmp',
+        '--vault-id', '1234',
+        '--vault-password-file', '/tmp/password',
+        '--output', '/tmp/inv_out.txt',
+        '--export',
+    ])
+
+    assert expected_command_start == rc.command
