@@ -14,6 +14,7 @@ from ansible_runner.config.runner import RunnerConfig, ExecutionMode
 from ansible_runner.interface import init_runner
 from ansible_runner.loader import ArtifactLoader
 from ansible_runner.exceptions import ConfigurationError
+from ansible_runner.utils import callback_mount
 
 try:
     Pattern = re._pattern_type
@@ -223,7 +224,7 @@ def test_prepare_env_directory_isolation_from_settings(mocker, project_fixtures)
     '''
     # Mock away the things that would actually prepare the isolation directory.
     mocker.patch('os.makedirs', return_value=True)
-    copy_tree = mocker.patch('distutils.dir_util.copy_tree')
+    copy_tree = mocker.patch('shutil.copytree')
     mkdtemp = mocker.patch('tempfile.mkdtemp')
     mkdtemp.return_value = '/tmp/runner/runner_di_XYZ'
     mocker.patch('ansible_runner.config.runner.RunnerConfig.build_process_isolation_temp_dir')
@@ -245,7 +246,7 @@ def test_prepare_env_directory_isolation_from_settings(mocker, project_fixtures)
     mkdtemp.assert_called_once_with(prefix='runner_di_', dir='/tmp/runner')
 
     # The project files should be copied to the isolation path.
-    copy_tree.assert_called_once_with(rc.project_dir, rc.directory_isolation_path, preserve_symlinks=True)
+    copy_tree.assert_called_once_with(rc.project_dir, rc.directory_isolation_path, symlinks=True)
 
 
 def test_prepare_inventory(mocker):
@@ -436,7 +437,6 @@ def test_prepare_with_defaults(mocker):
 
 def test_prepare(mocker):
     mocker.patch.dict('os.environ', {
-        'PYTHONPATH': '/python_path_via_environ',
         'AWX_LIB_DIRECTORY': '/awx_lib_directory_via_environ',
     })
     mocker.patch('os.makedirs', return_value=True)
@@ -462,14 +462,6 @@ def test_prepare(mocker):
     assert rc.env['ANSIBLE_RETRY_FILES_ENABLED'] == 'False'
     assert rc.env['ANSIBLE_HOST_KEY_CHECKING'] == 'False'
     assert rc.env['AWX_ISOLATED_DATA_DIR'] == '/'
-    assert rc.env['PYTHONPATH'] == '/python_path_via_environ:/awx_lib_directory_via_environ', \
-        "PYTHONPATH is the union of the env PYTHONPATH and AWX_LIB_DIRECTORY"
-
-    del rc.env['PYTHONPATH']
-    os.environ['PYTHONPATH'] = "/foo/bar/python_path_via_environ"
-    rc.prepare()
-    assert rc.env['PYTHONPATH'] == "/foo/bar/python_path_via_environ:/awx_lib_directory_via_environ", \
-        "PYTHONPATH is the union of the explicit env['PYTHONPATH'] override and AWX_LIB_DIRECTORY"
 
 
 def test_prepare_with_ssh_key(mocker):
@@ -571,7 +563,7 @@ def test_bwrap_process_isolation_defaults(mocker):
         'bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev', '/dev',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
         '--dir', '/tmp',
         '--ro-bind', '/bin', '/bin',
@@ -624,7 +616,7 @@ def test_bwrap_process_isolation_and_directory_isolation(mocker, patch_private_d
         'bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev', '/dev',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
         '--dir', '/tmp',
         '--ro-bind', '/bin', '/bin',
@@ -662,7 +654,7 @@ def test_process_isolation_settings(mocker, tmp_path):
         'not_bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev', '/dev',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
         '--dir', '/tmp',
         '--ro-bind', '/bin', '/bin',
@@ -697,56 +689,6 @@ def test_process_isolation_settings(mocker, tmp_path):
     assert rc.command[index + 15:] == ['--chdir', '/project', 'ansible-playbook', '-i', '/inventory', 'main.yaml']
 
 
-def test_profiling_plugin_settings(mocker):
-    mocker.patch('os.mkdir', return_value=True)
-
-    rc = RunnerConfig('/')
-    rc.playbook = 'main.yaml'
-    rc.command = 'ansible-playbook'
-    rc.resource_profiling = True
-    rc.resource_profiling_base_cgroup = 'ansible-runner'
-    rc.prepare()
-
-    expected_command_start = [
-        'cgexec',
-        '--sticky',
-        '-g',
-        'cpuacct,memory,pids:ansible-runner/{}'.format(rc.ident),
-        'ansible-playbook',
-        'main.yaml',
-    ]
-
-    assert expected_command_start == rc.command
-    assert 'main.yaml' in rc.command
-    assert rc.env['ANSIBLE_CALLBACK_WHITELIST'] == 'cgroup_perf_recap'
-    assert rc.env['CGROUP_CONTROL_GROUP'] == 'ansible-runner/{}'.format(rc.ident)
-    assert rc.env['CGROUP_OUTPUT_DIR'] == os.path.normpath(os.path.join(rc.private_data_dir, 'profiling_data'))
-    assert rc.env['CGROUP_OUTPUT_FORMAT'] == 'json'
-    assert rc.env['CGROUP_CPU_POLL_INTERVAL'] == '0.25'
-    assert rc.env['CGROUP_MEMORY_POLL_INTERVAL'] == '0.25'
-    assert rc.env['CGROUP_PID_POLL_INTERVAL'] == '0.25'
-    assert rc.env['CGROUP_FILE_PER_TASK'] == 'True'
-    assert rc.env['CGROUP_WRITE_FILES'] == 'True'
-    assert rc.env['CGROUP_DISPLAY_RECAP'] == 'False'
-
-
-def test_profiling_plugin_settings_with_custom_intervals(mocker):
-    mocker.patch('os.mkdir', return_value=True)
-
-    rc = RunnerConfig('/')
-    rc.playbook = 'main.yaml'
-    rc.command = 'ansible-playbook'
-    rc.resource_profiling = True
-    rc.resource_profiling_base_cgroup = 'ansible-runner'
-    rc.resource_profiling_cpu_poll_interval = '.5'
-    rc.resource_profiling_memory_poll_interval = '.75'
-    rc.resource_profiling_pid_poll_interval = '1.5'
-    rc.prepare()
-    assert rc.env['CGROUP_CPU_POLL_INTERVAL'] == '.5'
-    assert rc.env['CGROUP_MEMORY_POLL_INTERVAL'] == '.75'
-    assert rc.env['CGROUP_PID_POLL_INTERVAL'] == '1.5'
-
-
 def test_container_volume_mounting_with_Z(mocker, tmp_path):
     mocker.patch('os.path.isdir', return_value=True)
     mocker.patch('os.path.exists', return_value=True)
@@ -791,6 +733,7 @@ def test_containerization_settings(tmp_path, runtime, mocker):
 
     expected_command_start = [runtime, 'run', '--rm', '--tty', '--interactive', '--workdir', '/runner/project'] + \
         ['-v', '{}/:/runner/:Z'.format(rc.private_data_dir)] + \
+        ['-v', '{0}:{1}:Z'.format(*callback_mount())] + \
         ['-v', '/host1/:/container1/', '-v', '/host2/:/container2/'] + \
         ['--env-file', '{}/env.list'.format(rc.artifact_dir)] + \
         extra_container_args + \
